The input data for interrater agreement trial for determining whether the constructional patterns of the happiness words are metaphorical or not. The data include classifications in the post-discussion round.
1 |
An object of class tbl_df (inherits from tbl, data.frame) with 262 rows and 5 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.